import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="nlp-augment",
    version="1.0.2",
    description="It takes an sentence as an input and augment it",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/saroarjahan/nlp-augment",
    author="Md Saroar Jahan",
    author_email="mjahan18@edu.oulu.fi",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    packages=["augment"],
    include_package_data=True,
    install_requires=['wn==0.0.23','wordnet==0.0.1b2','pywsd==1.2.4','nltk==3.6.1'],
)
